#basic commands for people who dgaf about python
def add(a, b):
    return a + b
def mult(a, b): 
    return a * b
def sub(a, b): 
    return a - b 
def div(a, b): 
    return a / b 
def exp(a, power): 
    return a**power

    
       
    


from setuptools import setup, find_packages

classifiers = [
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python',
]

setup(
    name='sostupid',
    version='0.0.1',
    description='Sus Math Library For Cavemen',
    long_description = "0.0.1 Out Yay Cavemans Rise.\nI will add a description for this caveman product later don't worry",
    url='',
    author='Daniel Borro',
    author_email='',
    license = 'MIT',
    classifiers = classifiers, 
    keywords='', 
    packages=find_packages(), 
    install_requires=['']
)